==> nextcloud-24.0.10.tgz: nextcloud/apps/workflowengine/l10n/sq.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Operatori i dhënë nuk është i vlefshëm",
    "The given regular expression is invalid" : "Shprehja e rregullt e dhënë është e pavlefshme",
    "The given file size is invalid" : "Madhësia e dhënë e skedarit është e pavlefshme",
    "The given tag id is invalid" : "Id-ja e dhënë e etiketës është e pavlefshme",
    "The given IP range is invalid" : "Rangu i dhënë i IP është i pavlefshëm",
    "The given IP range is not valid for IPv4" : "Rangu i dhënë i IP nuk është i vlefshëm për IPv4",
    "The given IP range is not valid for IPv6" : "Rangu i dhënë i IP nuk është i vlefshëm për IPv6",
    "The given time span is invalid" : "Hapsira kohore e dhënë është e pavlefshme",
    "The given start time is invalid" : "Koha e fillimit është e pavlefshme",
    "The given end time is invalid" : "Koha e mbarimit është e pavlefshme",
    "The given group does not exist" : "Grupi i dhënë nuk ekziston",
    "File" : "Skedar ",
    "Operation #%s does not exist" : "Operacioni #%s nuk ekziston",
    "Operation %s does not exist" : "Operacioni %s nuk ekziston",
    "Operation %s is invalid" : "Operacioni %s është i pavlefshëm",
    "Check %s does not exist" : "Kontrolli %s nuk ekziston",
    "Check %s is invalid" : "Kontrolli %s është i pavlefshëm",
    "Check #%s does not exist" : "Kontrolli #%s nuk ekziston",
    "Check %s is invalid or does not exist" : "Kontrolli %s është i pavlefshëm ose nuk ekziston",
    "Folder" : "Skedari",
    "Images" : "Imazhe ",
    "Predefined URLs" : "URL të paracaktuara",
    "Files WebDAV" : "Skedarët WebDAV ",
    "Android client" : "Klient Android",
    "iOS client" : "Klient IOS",
    "Desktop client" : "Klient Desktop",
    "Thunderbird & Outlook addons" : "Shtojcat e Thunderbird & Outlook",
    "Cancel" : "Anullo",
    "Delete" : "Delete",
    "Save" : "Ruaj",
    "matches" : "përputhje",
    "does not match" : "nuk përputhet",
    "is" : "është",
    "is not" : "nuk është",
    "File name" : "Emri i skedarit",
    "File MIME type" : "Skedari i tipit MIME",
    "File size (upload)" : "Madhësia e skedarit (ngarko)",
    "less" : "më pak",
    "less or equals" : "më pak ose e barabartë",
    "greater or equals" : "më e madhe ose e barabartë",
    "greater" : "më e madhe",
    "Request remote address" : "Adresa e kërkesës remote",
    "matches IPv4" : "përputhet me IPv4",
    "does not match IPv4" : "nuk përputhet me IPv4",
    "matches IPv6" : "përputhet me IPv6",
    "does not match IPv6" : "nuk përputhet me IPv6",
    "File system tag" : "Etiketë e skedarit të sistemit",
    "is tagged with" : "është e etiketuar me",
    "is not tagged with" : "nuk është e etiketuar me",
    "Request URL" : "Kërko URL",
    "Request time" : "Koha e kërkesës",
    "between" : "midis",
    "not between" : "nuk është midis",
    "Request user agent" : "Kërko agjentin përdorues",
    "User group membership" : "Anëtarësia në grupet e përdoruesit",
    "is member of" : "është anëtarë i",
    "is not member of" : "nuk është anëtarë i",
    "No results" : "Asnjë rezultat",
    "%s (invisible)" : "%s (e padukshme)",
    "%s (restricted)" : "%s (e kufizuar)"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.7.tgz: nextcloud/apps/workflowengine/l10n/sq.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Operatori i dhënë nuk është i vlefshëm",
    "The given regular expression is invalid" : "Shprehja e rregullt e dhënë është e pavlefshme",
    "The given file size is invalid" : "Madhësia e dhënë e skedarit është e pavlefshme",
    "The given tag id is invalid" : "Id-ja e dhënë e etiketës është e pavlefshme",
    "The given IP range is invalid" : "Rangu i dhënë i IP është i pavlefshëm",
    "The given IP range is not valid for IPv4" : "Rangu i dhënë i IP nuk është i vlefshëm për IPv4",
    "The given IP range is not valid for IPv6" : "Rangu i dhënë i IP nuk është i vlefshëm për IPv6",
    "The given time span is invalid" : "Hapsira kohore e dhënë është e pavlefshme",
    "The given start time is invalid" : "Koha e fillimit është e pavlefshme",
    "The given end time is invalid" : "Koha e mbarimit është e pavlefshme",
    "The given group does not exist" : "Grupi i dhënë nuk ekziston",
    "File" : "Skedar ",
    "Operation #%s does not exist" : "Operacioni #%s nuk ekziston",
    "Operation %s does not exist" : "Operacioni %s nuk ekziston",
    "Operation %s is invalid" : "Operacioni %s është i pavlefshëm",
    "Check %s does not exist" : "Kontrolli %s nuk ekziston",
    "Check %s is invalid" : "Kontrolli %s është i pavlefshëm",
    "Check #%s does not exist" : "Kontrolli #%s nuk ekziston",
    "Check %s is invalid or does not exist" : "Kontrolli %s është i pavlefshëm ose nuk ekziston",
    "Folder" : "Skedari",
    "Images" : "Imazhe ",
    "Files WebDAV" : "Skedarët WebDAV ",
    "Android client" : "Klient Android",
    "iOS client" : "Klient IOS",
    "Desktop client" : "Klient Desktop",
    "Thunderbird & Outlook addons" : "Shtojcat e Thunderbird & Outlook",
    "Cancel" : "Anullo",
    "Delete" : "Delete",
    "Save" : "Ruaj",
    "matches" : "përputhje",
    "does not match" : "nuk përputhet",
    "is" : "është",
    "is not" : "nuk është",
    "File name" : "Emri i skedarit",
    "File MIME type" : "Skedari i tipit MIME",
    "File size (upload)" : "Madhësia e skedarit (ngarko)",
    "less" : "më pak",
    "less or equals" : "më pak ose e barabartë",
    "greater or equals" : "më e madhe ose e barabartë",
    "greater" : "më e madhe",
    "Request remote address" : "Adresa e kërkesës remote",
    "matches IPv4" : "përputhet me IPv4",
    "does not match IPv4" : "nuk përputhet me IPv4",
    "matches IPv6" : "përputhet me IPv6",
    "does not match IPv6" : "nuk përputhet me IPv6",
    "File system tag" : "Etiketë e skedarit të sistemit",
    "is tagged with" : "është e etiketuar me",
    "is not tagged with" : "nuk është e etiketuar me",
    "Request URL" : "Kërko URL",
    "Request time" : "Koha e kërkesës",
    "between" : "midis",
    "not between" : "nuk është midis",
    "Request user agent" : "Kërko agjentin përdorues",
    "User group membership" : "Anëtarësia në grupet e përdoruesit",
    "is member of" : "është anëtarë i",
    "is not member of" : "nuk është anëtarë i",
    "No results" : "Asnjë rezultat",
    "%s (invisible)" : "%s (e padukshme)",
    "%s (restricted)" : "%s (e kufizuar)",
    "Predefined URLs" : "URL të paracaktuara"
},
"nplurals=2; plural=(n != 1);");
